@@ -17,13 +17,7 @@ from typing import Any, Dict, List, Type, overload
 
 from botocore.client import ClientMeta
 
-from .paginator import (
-    AnyInstanceInServiceWaiter,
-    DescribeAccountLimitsPaginator,
-    DescribeLoadBalancersPaginator,
-    InstanceDeregisteredWaiter,
-    InstanceInServiceWaiter,
-)
+from .paginator import DescribeAccountLimitsPaginator, DescribeLoadBalancersPaginator
 from .type_defs import (
     AddAvailabilityZonesOutputTypeDef,
     ApplySecurityGroupsToLoadBalancerOutputTypeDef,
@@ -50,6 +44,7 @@ from .type_defs import (
     TagKeyOnlyTypeDef,
     TagTypeDef,
 )
+from .waiter import AnyInstanceInServiceWaiter, InstanceDeregisteredWaiter, InstanceInServiceWaiter
 
 if sys.version_info >= (3, 8):
     from typing import Literal
@@ -96,7 +91,7 @@ class Exceptions:
 
 class ElasticLoadBalancingClient:
     """
-    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.72/reference/services/elb.html#ElasticLoadBalancing.Client)
+    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.73/reference/services/elb.html#ElasticLoadBalancing.Client)
     [Show boto3-stubs documentation](./client.md)
     """
 
@@ -105,7 +100,7 @@ class ElasticLoadBalancingClient:
 
     def add_tags(self, LoadBalancerNames: List[str], Tags: List["TagTypeDef"]) -> Dict[str, Any]:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.72/reference/services/elb.html#ElasticLoadBalancing.Client.add_tags)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.73/reference/services/elb.html#ElasticLoadBalancing.Client.add_tags)
         [Show boto3-stubs documentation](./client.md#add_tags)
         """
 
@@ -113,7 +108,7 @@ class ElasticLoadBalancingClient:
         self, LoadBalancerName: str, SecurityGroups: List[str]
     ) -> ApplySecurityGroupsToLoadBalancerOutputTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.72/reference/services/elb.html#ElasticLoadBalancing.Client.apply_security_groups_to_load_balancer)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.73/reference/services/elb.html#ElasticLoadBalancing.Client.apply_security_groups_to_load_balancer)
         [Show boto3-stubs documentation](./client.md#apply_security_groups_to_load_balancer)
         """
 
@@ -121,13 +116,13 @@ class ElasticLoadBalancingClient:
         self, LoadBalancerName: str, Subnets: List[str]
     ) -> AttachLoadBalancerToSubnetsOutputTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.72/reference/services/elb.html#ElasticLoadBalancing.Client.attach_load_balancer_to_subnets)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.73/reference/services/elb.html#ElasticLoadBalancing.Client.attach_load_balancer_to_subnets)
         [Show boto3-stubs documentation](./client.md#attach_load_balancer_to_subnets)
         """
 
     def can_paginate(self, operation_name: str) -> bool:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.72/reference/services/elb.html#ElasticLoadBalancing.Client.can_paginate)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.73/reference/services/elb.html#ElasticLoadBalancing.Client.can_paginate)
         [Show boto3-stubs documentation](./client.md#can_paginate)
         """
 
@@ -135,7 +130,7 @@ class ElasticLoadBalancingClient:
         self, LoadBalancerName: str, HealthCheck: "HealthCheckTypeDef"
     ) -> ConfigureHealthCheckOutputTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.72/reference/services/elb.html#ElasticLoadBalancing.Client.configure_health_check)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.73/reference/services/elb.html#ElasticLoadBalancing.Client.configure_health_check)
         [Show boto3-stubs documentation](./client.md#configure_health_check)
         """
 
@@ -143,7 +138,7 @@ class ElasticLoadBalancingClient:
         self, LoadBalancerName: str, PolicyName: str, CookieName: str
     ) -> Dict[str, Any]:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.72/reference/services/elb.html#ElasticLoadBalancing.Client.create_app_cookie_stickiness_policy)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.73/reference/services/elb.html#ElasticLoadBalancing.Client.create_app_cookie_stickiness_policy)
         [Show boto3-stubs documentation](./client.md#create_app_cookie_stickiness_policy)
         """
 
@@ -151,7 +146,7 @@ class ElasticLoadBalancingClient:
         self, LoadBalancerName: str, PolicyName: str, CookieExpirationPeriod: int = None
     ) -> Dict[str, Any]:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.72/reference/services/elb.html#ElasticLoadBalancing.Client.create_lb_cookie_stickiness_policy)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.73/reference/services/elb.html#ElasticLoadBalancing.Client.create_lb_cookie_stickiness_policy)
         [Show boto3-stubs documentation](./client.md#create_lb_cookie_stickiness_policy)
         """
 
@@ -166,7 +161,7 @@ class ElasticLoadBalancingClient:
         Tags: List["TagTypeDef"] = None,
     ) -> CreateAccessPointOutputTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.72/reference/services/elb.html#ElasticLoadBalancing.Client.create_load_balancer)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.73/reference/services/elb.html#ElasticLoadBalancing.Client.create_load_balancer)
         [Show boto3-stubs documentation](./client.md#create_load_balancer)
         """
 
@@ -174,7 +169,7 @@ class ElasticLoadBalancingClient:
         self, LoadBalancerName: str, Listeners: List["ListenerTypeDef"]
     ) -> Dict[str, Any]:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.72/reference/services/elb.html#ElasticLoadBalancing.Client.create_load_balancer_listeners)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.73/reference/services/elb.html#ElasticLoadBalancing.Client.create_load_balancer_listeners)
         [Show boto3-stubs documentation](./client.md#create_load_balancer_listeners)
         """
 
@@ -186,13 +181,13 @@ class ElasticLoadBalancingClient:
         PolicyAttributes: List[PolicyAttributeTypeDef] = None,
     ) -> Dict[str, Any]:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.72/reference/services/elb.html#ElasticLoadBalancing.Client.create_load_balancer_policy)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.73/reference/services/elb.html#ElasticLoadBalancing.Client.create_load_balancer_policy)
         [Show boto3-stubs documentation](./client.md#create_load_balancer_policy)
         """
 
     def delete_load_balancer(self, LoadBalancerName: str) -> Dict[str, Any]:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.72/reference/services/elb.html#ElasticLoadBalancing.Client.delete_load_balancer)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.73/reference/services/elb.html#ElasticLoadBalancing.Client.delete_load_balancer)
         [Show boto3-stubs documentation](./client.md#delete_load_balancer)
         """
 
@@ -200,13 +195,13 @@ class ElasticLoadBalancingClient:
         self, LoadBalancerName: str, LoadBalancerPorts: List[int]
     ) -> Dict[str, Any]:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.72/reference/services/elb.html#ElasticLoadBalancing.Client.delete_load_balancer_listeners)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.73/reference/services/elb.html#ElasticLoadBalancing.Client.delete_load_balancer_listeners)
         [Show boto3-stubs documentation](./client.md#delete_load_balancer_listeners)
         """
 
     def delete_load_balancer_policy(self, LoadBalancerName: str, PolicyName: str) -> Dict[str, Any]:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.72/reference/services/elb.html#ElasticLoadBalancing.Client.delete_load_balancer_policy)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.73/reference/services/elb.html#ElasticLoadBalancing.Client.delete_load_balancer_policy)
         [Show boto3-stubs documentation](./client.md#delete_load_balancer_policy)
         """
 
@@ -214,7 +209,7 @@ class ElasticLoadBalancingClient:
         self, LoadBalancerName: str, Instances: List["InstanceTypeDef"]
     ) -> DeregisterEndPointsOutputTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.72/reference/services/elb.html#ElasticLoadBalancing.Client.deregister_instances_from_load_balancer)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.73/reference/services/elb.html#ElasticLoadBalancing.Client.deregister_instances_from_load_balancer)
         [Show boto3-stubs documentation](./client.md#deregister_instances_from_load_balancer)
         """
 
@@ -222,7 +217,7 @@ class ElasticLoadBalancingClient:
         self, Marker: str = None, PageSize: int = None
     ) -> DescribeAccountLimitsOutputTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.72/reference/services/elb.html#ElasticLoadBalancing.Client.describe_account_limits)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.73/reference/services/elb.html#ElasticLoadBalancing.Client.describe_account_limits)
         [Show boto3-stubs documentation](./client.md#describe_account_limits)
         """
 
@@ -230,7 +225,7 @@ class ElasticLoadBalancingClient:
         self, LoadBalancerName: str, Instances: List["InstanceTypeDef"] = None
     ) -> DescribeEndPointStateOutputTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.72/reference/services/elb.html#ElasticLoadBalancing.Client.describe_instance_health)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.73/reference/services/elb.html#ElasticLoadBalancing.Client.describe_instance_health)
         [Show boto3-stubs documentation](./client.md#describe_instance_health)
         """
 
@@ -238,7 +233,7 @@ class ElasticLoadBalancingClient:
         self, LoadBalancerName: str
     ) -> DescribeLoadBalancerAttributesOutputTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.72/reference/services/elb.html#ElasticLoadBalancing.Client.describe_load_balancer_attributes)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.73/reference/services/elb.html#ElasticLoadBalancing.Client.describe_load_balancer_attributes)
         [Show boto3-stubs documentation](./client.md#describe_load_balancer_attributes)
         """
 
@@ -246,7 +241,7 @@ class ElasticLoadBalancingClient:
         self, LoadBalancerName: str = None, PolicyNames: List[str] = None
     ) -> DescribeLoadBalancerPoliciesOutputTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.72/reference/services/elb.html#ElasticLoadBalancing.Client.describe_load_balancer_policies)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.73/reference/services/elb.html#ElasticLoadBalancing.Client.describe_load_balancer_policies)
         [Show boto3-stubs documentation](./client.md#describe_load_balancer_policies)
         """
 
@@ -254,7 +249,7 @@ class ElasticLoadBalancingClient:
         self, PolicyTypeNames: List[str] = None
     ) -> DescribeLoadBalancerPolicyTypesOutputTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.72/reference/services/elb.html#ElasticLoadBalancing.Client.describe_load_balancer_policy_types)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.73/reference/services/elb.html#ElasticLoadBalancing.Client.describe_load_balancer_policy_types)
         [Show boto3-stubs documentation](./client.md#describe_load_balancer_policy_types)
         """
 
@@ -262,13 +257,13 @@ class ElasticLoadBalancingClient:
         self, LoadBalancerNames: List[str] = None, Marker: str = None, PageSize: int = None
     ) -> DescribeAccessPointsOutputTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.72/reference/services/elb.html#ElasticLoadBalancing.Client.describe_load_balancers)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.73/reference/services/elb.html#ElasticLoadBalancing.Client.describe_load_balancers)
         [Show boto3-stubs documentation](./client.md#describe_load_balancers)
         """
 
     def describe_tags(self, LoadBalancerNames: List[str]) -> DescribeTagsOutputTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.72/reference/services/elb.html#ElasticLoadBalancing.Client.describe_tags)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.73/reference/services/elb.html#ElasticLoadBalancing.Client.describe_tags)
         [Show boto3-stubs documentation](./client.md#describe_tags)
         """
 
@@ -276,7 +271,7 @@ class ElasticLoadBalancingClient:
         self, LoadBalancerName: str, Subnets: List[str]
     ) -> DetachLoadBalancerFromSubnetsOutputTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.72/reference/services/elb.html#ElasticLoadBalancing.Client.detach_load_balancer_from_subnets)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.73/reference/services/elb.html#ElasticLoadBalancing.Client.detach_load_balancer_from_subnets)
         [Show boto3-stubs documentation](./client.md#detach_load_balancer_from_subnets)
         """
 
@@ -284,7 +279,7 @@ class ElasticLoadBalancingClient:
         self, LoadBalancerName: str, AvailabilityZones: List[str]
     ) -> RemoveAvailabilityZonesOutputTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.72/reference/services/elb.html#ElasticLoadBalancing.Client.disable_availability_zones_for_load_balancer)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.73/reference/services/elb.html#ElasticLoadBalancing.Client.disable_availability_zones_for_load_balancer)
         [Show boto3-stubs documentation](./client.md#disable_availability_zones_for_load_balancer)
         """
 
@@ -292,7 +287,7 @@ class ElasticLoadBalancingClient:
         self, LoadBalancerName: str, AvailabilityZones: List[str]
     ) -> AddAvailabilityZonesOutputTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.72/reference/services/elb.html#ElasticLoadBalancing.Client.enable_availability_zones_for_load_balancer)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.73/reference/services/elb.html#ElasticLoadBalancing.Client.enable_availability_zones_for_load_balancer)
         [Show boto3-stubs documentation](./client.md#enable_availability_zones_for_load_balancer)
         """
 
@@ -304,7 +299,7 @@ class ElasticLoadBalancingClient:
         HttpMethod: str = None,
     ) -> str:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.72/reference/services/elb.html#ElasticLoadBalancing.Client.generate_presigned_url)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.73/reference/services/elb.html#ElasticLoadBalancing.Client.generate_presigned_url)
         [Show boto3-stubs documentation](./client.md#generate_presigned_url)
         """
 
@@ -312,7 +307,7 @@ class ElasticLoadBalancingClient:
         self, LoadBalancerName: str, LoadBalancerAttributes: "LoadBalancerAttributesTypeDef"
     ) -> ModifyLoadBalancerAttributesOutputTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.72/reference/services/elb.html#ElasticLoadBalancing.Client.modify_load_balancer_attributes)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.73/reference/services/elb.html#ElasticLoadBalancing.Client.modify_load_balancer_attributes)
         [Show boto3-stubs documentation](./client.md#modify_load_balancer_attributes)
         """
 
@@ -320,7 +315,7 @@ class ElasticLoadBalancingClient:
         self, LoadBalancerName: str, Instances: List["InstanceTypeDef"]
     ) -> RegisterEndPointsOutputTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.72/reference/services/elb.html#ElasticLoadBalancing.Client.register_instances_with_load_balancer)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.73/reference/services/elb.html#ElasticLoadBalancing.Client.register_instances_with_load_balancer)
         [Show boto3-stubs documentation](./client.md#register_instances_with_load_balancer)
         """
 
@@ -328,7 +323,7 @@ class ElasticLoadBalancingClient:
         self, LoadBalancerNames: List[str], Tags: List[TagKeyOnlyTypeDef]
     ) -> Dict[str, Any]:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.72/reference/services/elb.html#ElasticLoadBalancing.Client.remove_tags)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.73/reference/services/elb.html#ElasticLoadBalancing.Client.remove_tags)
         [Show boto3-stubs documentation](./client.md#remove_tags)
         """
 
@@ -336,7 +331,7 @@ class ElasticLoadBalancingClient:
         self, LoadBalancerName: str, LoadBalancerPort: int, SSLCertificateId: str
     ) -> Dict[str, Any]:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.72/reference/services/elb.html#ElasticLoadBalancing.Client.set_load_balancer_listener_ssl_certificate)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.73/reference/services/elb.html#ElasticLoadBalancing.Client.set_load_balancer_listener_ssl_certificate)
         [Show boto3-stubs documentation](./client.md#set_load_balancer_listener_ssl_certificate)
         """
 
@@ -344,7 +339,7 @@ class ElasticLoadBalancingClient:
         self, LoadBalancerName: str, InstancePort: int, PolicyNames: List[str]
     ) -> Dict[str, Any]:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.72/reference/services/elb.html#ElasticLoadBalancing.Client.set_load_balancer_policies_for_backend_server)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.73/reference/services/elb.html#ElasticLoadBalancing.Client.set_load_balancer_policies_for_backend_server)
         [Show boto3-stubs documentation](./client.md#set_load_balancer_policies_for_backend_server)
         """
 
@@ -352,7 +347,7 @@ class ElasticLoadBalancingClient:
         self, LoadBalancerName: str, LoadBalancerPort: int, PolicyNames: List[str]
     ) -> Dict[str, Any]:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.72/reference/services/elb.html#ElasticLoadBalancing.Client.set_load_balancer_policies_of_listener)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.73/reference/services/elb.html#ElasticLoadBalancing.Client.set_load_balancer_policies_of_listener)
         [Show boto3-stubs documentation](./client.md#set_load_balancer_policies_of_listener)
         """
 
@@ -361,7 +356,7 @@ class ElasticLoadBalancingClient:
         self, operation_name: Literal["describe_account_limits"]
     ) -> DescribeAccountLimitsPaginator:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.72/reference/services/elb.html#ElasticLoadBalancing.Paginator.DescribeAccountLimits)[Show boto3-stubs documentation](./paginators.md#describeaccountlimitspaginator)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.73/reference/services/elb.html#ElasticLoadBalancing.Paginator.DescribeAccountLimits)[Show boto3-stubs documentation](./paginators.md#describeaccountlimitspaginator)
         """
 
     @overload
@@ -369,7 +364,7 @@ class ElasticLoadBalancingClient:
         self, operation_name: Literal["describe_load_balancers"]
     ) -> DescribeLoadBalancersPaginator:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.72/reference/services/elb.html#ElasticLoadBalancing.Paginator.DescribeLoadBalancers)[Show boto3-stubs documentation](./paginators.md#describeloadbalancerspaginator)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.73/reference/services/elb.html#ElasticLoadBalancing.Paginator.DescribeLoadBalancers)[Show boto3-stubs documentation](./paginators.md#describeloadbalancerspaginator)
         """
 
     @overload
@@ -377,7 +372,7 @@ class ElasticLoadBalancingClient:
         self, waiter_name: Literal["any_instance_in_service"]
     ) -> AnyInstanceInServiceWaiter:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.72/reference/services/elb.html#ElasticLoadBalancing.Waiter.any_instance_in_service)[Show boto3-stubs documentation](./waiters.md#anyinstanceinservicewaiter)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.73/reference/services/elb.html#ElasticLoadBalancing.Waiter.any_instance_in_service)[Show boto3-stubs documentation](./waiters.md#anyinstanceinservicewaiter)
         """
 
     @overload
@@ -385,11 +380,11 @@ class ElasticLoadBalancingClient:
         self, waiter_name: Literal["instance_deregistered"]
     ) -> InstanceDeregisteredWaiter:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.72/reference/services/elb.html#ElasticLoadBalancing.Waiter.instance_deregistered)[Show boto3-stubs documentation](./waiters.md#instancederegisteredwaiter)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.73/reference/services/elb.html#ElasticLoadBalancing.Waiter.instance_deregistered)[Show boto3-stubs documentation](./waiters.md#instancederegisteredwaiter)
         """
 
     @overload
     def get_waiter(self, waiter_name: Literal["instance_in_service"]) -> InstanceInServiceWaiter:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.72/reference/services/elb.html#ElasticLoadBalancing.Waiter.instance_in_service)[Show boto3-stubs documentation](./waiters.md#instanceinservicewaiter)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.73/reference/services/elb.html#ElasticLoadBalancing.Waiter.instance_in_service)[Show boto3-stubs documentation](./waiters.md#instanceinservicewaiter)
         """
